Change R package name from 'templateRpackage' to the chosen new name, by replacing all mentions to 'templateRpackage' within files and file names. Note this function is potentially dangerous, as it changes file names and contents, and deleted the entire 'man' folder. Only run this function just after creating the new repository from the template.
Details
Inspired on the changer package by Jouni Helske.